@@ -1,7 +1,7 @@
 use std::{
     intrinsics::transmute,
     io::{Read, Result},
-    mem::{size_of, zeroed},
+    mem::size_of,
     ops::{Add, Mul, Rem, Sub},
     ptr::addr_of,
 };
@@ -23,6 +23,17 @@ pub struct ZestRand {
     byte_offset: usize,
 }
 impl ZestRand {
+    //Create new ZestRand instance
+    #[inline(always)]
+    pub fn new(seed: Option<ZestBlock>) -> ZestRand {
+        let mut initial = ZestRand {
+            seed: seed.unwrap_or_default(),
+            hash_output: ZestBlock::default(),
+            byte_offset: 0
+        };
+        initial.hash_output = zest4096(initial.seed);
+        initial
+    }
     // (Re)seed the CSPRNG, and start at beginning of block + offset.
     // Doesn't check for identical seeds before rehashing.
     #[inline(always)]
@@ -121,9 +132,7 @@ impl Default for ZestRand {
         // Safety: All fields are set to 0, and none
         // are pointers to any other object.
         // The initial block is also generated.
-        let mut initial: Self = unsafe { zeroed() };
-        initial.hash_output = zest4096(initial.seed);
-        initial
+        Self::new(None)
     }
 }
 
